==> wire-grpc-client-3.2.0-javadoc.jar: wire-schema/com.squareup.wire.schema/-field/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [Field](./index.md)

# Field

`class Field`

### Types

| Name | Summary |
|---|---|
| [EncodeMode](-encode-mode/index.md) | `enum class EncodeMode` |
| [Label](-label/index.md) | `enum class Label` |

### Properties

| Name | Summary |
|---|---|
| [default](default.md) | `val default: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?` |
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [encodeMode](encode-mode.md) | `var encodeMode: `[`EncodeMode`](-encode-mode/index.md)`?` |
| [isDeprecated](is-deprecated.md) | `val isDeprecated: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isExtension](is-extension.md) | `val isExtension: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isOneOf](is-one-of.md) | `val isOneOf: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isPacked](is-packed.md) | `val isPacked: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isRedacted](is-redacted.md) | `var isRedacted: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isRepeated](is-repeated.md) | `val isRepeated: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [label](label.md) | `val label: `[`Label`](-label/index.md)`?`<br>May be null for proto3 fields, or one-of's. |
| [location](location.md) | `val location: `[`Location`](../-location/index.md) |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [options](options.md) | `val options: `[`Options`](../-options/index.md) |
| [packageName](package-name.md) | `val packageName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?` |
| [qualifiedName](qualified-name.md) | `val qualifiedName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)<br>Returns this field's name, prefixed with its package name. Uniquely identifies extension fields, such as in options. |
| [tag](tag.md) | `val tag: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [type](type.md) | `var type: `[`ProtoType`](../-proto-type/index.md)`?` |

### Functions

| Name | Summary |
|---|---|
| [link](link.md) | `fun link(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [linkOptions](link-options.md) | `fun linkOptions(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`, enclosingType: `[`ProtoType`](../-proto-type/index.md)`): `[`Field`](./index.md)`?` |
| [toString](to-string.md) | `fun toString(): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [validate](validate.md) | `fun validate(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Companion Object Functions

| Name | Summary |
|---|---|
| [fromElements](from-elements.md) | `fun fromElements(packageName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?, fieldElements: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`FieldElement`](../../com.squareup.wire.schema.internal.parser/-field-element/index.md)`>, extension: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`, oneOf: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): <ERROR CLASS>` |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`, enclosingType: `[`ProtoType`](../-proto-type/index.md)`, fields: `[`Collection`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)`<`[`Field`](./index.md)`>): <ERROR CLASS>` |
| [retainLinked](retain-linked.md) | `fun retainLinked(fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](./index.md)`>): <ERROR CLASS>` |
| [toElements](to-elements.md) | `fun toElements(fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](./index.md)`>): <ERROR CLASS>` |

==> wire-grpc-client-3.2.2-javadoc.jar: wire-schema/com.squareup.wire.schema/-field/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema](../index.md) / [Field](./index.md)

# Field

`class Field`

### Types

| Name | Summary |
|---|---|
| [EncodeMode](-encode-mode/index.md) | `enum class EncodeMode` |
| [Label](-label/index.md) | `enum class Label` |

### Properties

| Name | Summary |
|---|---|
| [default](default.md) | `val default: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?` |
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [encodeMode](encode-mode.md) | `var encodeMode: `[`EncodeMode`](-encode-mode/index.md)`?` |
| [isDeprecated](is-deprecated.md) | `val isDeprecated: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isExtension](is-extension.md) | `val isExtension: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isOneOf](is-one-of.md) | `val isOneOf: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isPacked](is-packed.md) | `val isPacked: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isRedacted](is-redacted.md) | `var isRedacted: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isRepeated](is-repeated.md) | `val isRepeated: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [jsonName](json-name.md) | `var jsonName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?` |
| [label](label.md) | `val label: `[`Label`](-label/index.md)`?`<br>May be null for proto3 fields, or one-of's. |
| [location](location.md) | `val location: `[`Location`](../-location/index.md) |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [options](options.md) | `val options: `[`Options`](../-options/index.md) |
| [packageName](package-name.md) | `val packageName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?` |
| [qualifiedName](qualified-name.md) | `val qualifiedName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)<br>Returns this field's name, prefixed with its package name. Uniquely identifies extension fields, such as in options. |
| [tag](tag.md) | `val tag: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [type](type.md) | `var type: `[`ProtoType`](../-proto-type/index.md)`?` |

### Functions

| Name | Summary |
|---|---|
| [link](link.md) | `fun link(linker: `[`Linker`](../-linker/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [linkOptions](link-options.md) | `fun linkOptions(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`, enclosingType: `[`ProtoType`](../-proto-type/index.md)`): `[`Field`](./index.md)`?` |
| [toString](to-string.md) | `fun toString(): `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [validate](validate.md) | `fun validate(linker: `[`Linker`](../-linker/index.md)`, syntaxRules: `[`SyntaxRules`](../-syntax-rules/index.md)`): `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html) |

### Companion Object Functions

| Name | Summary |
|---|---|
| [fromElements](from-elements.md) | `fun fromElements(packageName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?, fieldElements: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`FieldElement`](../../com.squareup.wire.schema.internal.parser/-field-element/index.md)`>, extension: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`, oneOf: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`): <ERROR CLASS>` |
| [retainAll](retain-all.md) | `fun retainAll(schema: `[`Schema`](../-schema/index.md)`, markSet: `[`MarkSet`](../-mark-set/index.md)`, enclosingType: `[`ProtoType`](../-proto-type/index.md)`, fields: `[`Collection`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)`<`[`Field`](./index.md)`>): <ERROR CLASS>` |
| [retainLinked](retain-linked.md) | `fun retainLinked(fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](./index.md)`>): <ERROR CLASS>` |
| [toElements](to-elements.md) | `fun toElements(fields: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`Field`](./index.md)`>): <ERROR CLASS>` |
